pub struct CachedEntry {
pub rows: Vec<DecodedValue>,
pub tags: Vec<String>,
}Expand description
One cache entry: the cached rows plus the tags a write to any of which must invalidate it — stored together so invalidation never needs a second lookup to find out what a key was tagged with.
Fields
rows: Vec<DecodedValue>Trait Implementations
Sourceimpl Archive for CachedEntry
impl Archive for CachedEntry
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCachedEntry
type Archived = ArchivedCachedEntry
The archived representation of this type. Read more
Sourcetype Resolver = CachedEntryResolver
type Resolver = CachedEntryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for CachedEntry
impl Clone for CachedEntry
Sourceimpl Debug for CachedEntry
impl Debug for CachedEntry
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CachedEntry, __D> for Archived<CachedEntry>where
Vec<DecodedValue>: Archive,
<Vec<DecodedValue> as Archive>::Archived: Deserialize<Vec<DecodedValue>, __D>,
Vec<String>: Archive,
<Vec<String> as Archive>::Archived: Deserialize<Vec<String>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<CachedEntry, __D> for Archived<CachedEntry>where
Vec<DecodedValue>: Archive,
<Vec<DecodedValue> as Archive>::Archived: Deserialize<Vec<DecodedValue>, __D>,
Vec<String>: Archive,
<Vec<String> as Archive>::Archived: Deserialize<Vec<String>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CachedEntry, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CachedEntry, <__D as Fallible>::Error>
Deserializes using the given deserializer